# colorsynth

[![tests](https://github.com/sun-data/colorsynth/actions/workflows/tests.yml/badge.svg)](https://github.com/sun-data/colorsynth/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/sun-data/colorsynth/graph/badge.svg?token=8QettIppCi)](https://codecov.io/gh/sun-data/colorsynth)
[![Black](https://github.com/sun-data/colorsynth/actions/workflows/black.yml/badge.svg)](https://github.com/sun-data/colorsynth/actions/workflows/black.yml)
[![Documentation Status](https://readthedocs.org/projects/colorsynth/badge/?version=latest)](https://colorsynth.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/colorsynth.svg)](https://badge.fury.io/py/colorsynth)

A Python library for creating false-color images from 3D Numpy arrays of spectral intensity.

## Installation

`colorsynth` is available on the Python Package Index and can be installed using `pip`:
```
pip install colorsynth
```

## Gallery

An Si IV 1403 A spectroheliogram captured by the [Interface Region Imaging Spectrograph](iris.lmsal.com) and colorized using 
[`colorsynth.rgb()`](https://colorsynth.readthedocs.io/en/latest/_autosummary/colorsynth.rgb.html#colorsynth.rgb). 
The code to create this image can be found in the [documentation](https://colorsynth.readthedocs.io/).

![IRIS spectroheliogram](https://colorsynth.readthedocs.io/en/latest/_images/index_0_1.png)
